<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://agilelogix.com
 * @since      1.0.0
 *
 * @package    AgileStoreLocator
 * @subpackage AgileStoreLocator/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    AgileStoreLocator
 * @subpackage AgileStoreLocator/includes
 * @author     Your Name <support@agilelogix.com>
 */
class AgileStoreLocator {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      AgileStoreLocator_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $AgileStoreLocator    The string used to uniquely identify this plugin.
	 */
	protected $AgileStoreLocator;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->AgileStoreLocator = 'agile-store-locator';
		$this->version = ASL_CVERSION;

		$this->load_dependencies();
		$this->set_locale();
		
		//	ADMIN HOOKS
		$this->plugin_admin  = new AgileStoreLocator_Admin( $this->get_AgileStoreLocator(), $this->get_version() );

		//	FRONTEND Public
		$this->plugin_public  = new AgileStoreLocator_Public( $this->get_AgileStoreLocator(), $this->get_version() );

		//	FRONTEND Request
		$this->public_request = new AgileStoreLocator_Request();
		
		add_action('wp_ajax_asl_load_stores', array($this->public_request, 'load_stores'));	
		add_action('wp_ajax_nopriv_asl_load_stores', array($this->public_request, 'load_stores'));

		add_action('wp_ajax_asl_lead_request', array($this->public_request, 'lead_request'));	
		add_action('wp_ajax_nopriv_asl_lead_request', array($this->public_request, 'lead_request'));


		if (is_admin())
			$this->define_admin_hooks();
		else
			$this->define_public_hooks();


		//	Remove Google Maps scripts
		if(get_option('asl-remove_maps_script') == '1') {

			add_filter('script_loader_tag', array($this, 'removeGoogleMapsTag'), 9999999, 3);

			//	Uncomment (Remove //) this line to include Maps Google script on All Pages
			//	$this->plugin_public->enqueue_scripts();
		}

		add_action( 'init', array($this, 'add_stores_feed') );
	}

	/**
	 * [add_stores_feed Add the Stores Feed]
	 */
	public function add_stores_feed() {

		add_feed( 'stores-feed', array($this, 'generateFeeds') );
	}


	/**
	 * Remove all the other google maps scripts
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function removeGoogleMapsTag($tag, $handle, $src)
	{
	
		if(preg_match('/maps\.google/i', $src))
		{
			if($handle != 'asl_google_maps')
				return '';
		}

		return $tag;
	}


	/**
	 * [generateFeeds Generate the Feeds]
	 * @param  string $output [description]
	 * @return [type]         [description]
	 */
	public function generateFeeds($output = 'xml') {


		// Instantiate the class object
		$this->plugin_feed = $ASLFeed = ASLFeed::getInstance();

		$ASLFeed->displayStores();die;	
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - AgileStoreLocator_Loader. Orchestrates the hooks of the plugin.
	 * - AgileStoreLocator_i18n. Defines internationalization functionality.
	 * - AgileStoreLocator_Admin. Defines all hooks for the admin area.
	 * - AgileStoreLocator_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once ASL_PLUGIN_PATH . 'includes/class-agile-store-locator-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once ASL_PLUGIN_PATH . 'includes/class-agile-store-locator-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once ASL_PLUGIN_PATH . 'admin/class-agile-store-locator-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once ASL_PLUGIN_PATH . 'includes/frontend/class-agile-store-locator-public.php';


		/**
		 * The class responsible for defining all public ajax requests
		 * side of the site.
		 */
		require_once ASL_PLUGIN_PATH . 'includes/frontend/class-agile-store-locator-request.php';

		/**
		 * The class responsible for feeds
		 * side of the site.
		 */
		require_once ASL_PLUGIN_PATH . 'includes/class-agile-store-locator-feed.php';

		$this->loader = new AgileStoreLocator_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the AgileStoreLocator_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new AgileStoreLocator_i18n();
		$plugin_i18n->set_domain( $this->get_AgileStoreLocator() );

		//$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

		add_action( 'plugins_loaded', array($this, 'load_plugin_textdomain') );
		//$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	public function load_plugin_textdomain() {


		$domain 		= 'asl_locator';
		$admin_domain 	= 'asl_admin';


		$mo_file  			= WP_LANG_DIR . '/' . $domain . '/' . $domain . '-' . get_locale() . '.mo';
		$mo_admin_file  = WP_LANG_DIR . '/' . $admin_domain . '/' . $admin_domain . '-' . get_locale() . '.mo';

		//	$mo_file, /wp-content/languages/asl_locator/asl_locator-en_US.mo
		
		//Plugin Frontend
		load_textdomain( $domain, $mo_file ); 
		load_plugin_textdomain( $domain, false, ASL_BASE_PATH . '/languages/');


		//Load the Admin Language File
		if (is_admin()) {
			
			load_textdomain( $admin_domain, $mo_admin_file ); 
			load_plugin_textdomain( $admin_domain, false, ASL_BASE_PATH . '/languages/');
		}

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

	
		//ad menu if u r an admin
		add_action('admin_menu', array($this,'add_admin_menu'));
		add_action('wp_ajax_asl_upload_logo', array($this->plugin_admin, 'upload_logo'));
		/*For Stores*/
		add_action('wp_ajax_asl_add_store', array($this->plugin_admin, 'add_new_store'));	
		add_action('wp_ajax_asl_delete_all_stores', array($this->plugin_admin, 'admin_delete_all_stores'));	
		add_action('wp_ajax_asl_update_a_store', array($this->plugin_admin, 'update_store'));
		add_action('wp_ajax_asl_get_store_list', array($this->plugin_admin, 'get_store_list'));	
		add_action('wp_ajax_asl_delete_store', array($this->plugin_admin, 'delete_store'));	
		add_action('wp_ajax_asl_duplicate_store', array($this->plugin_admin, 'duplicate_store'));	
		add_action('wp_ajax_asl_remove_duplicates', array($this->plugin_admin, 'remove_duplicates'));	
		add_action('wp_ajax_asl_validate_coords', array($this->plugin_admin, 'validate_coordinates'));	
		add_action('wp_ajax_asl_store_status', array($this->plugin_admin, 'store_status'));	

		/*Categories*/
		add_action('wp_ajax_asl_add_categories', array($this->plugin_admin, 'add_category'));
		add_action('wp_ajax_asl_delete_category', array($this->plugin_admin, 'delete_category'));
		add_action('wp_ajax_asl_update_category', array($this->plugin_admin, 'update_category'));
		add_action('wp_ajax_asl_get_category_byid', array($this->plugin_admin, 'get_category_by_id'));
		add_action('wp_ajax_asl_get_categories', array($this->plugin_admin, 'get_categories'));	


		/*Import and settings*/
		add_action('wp_ajax_asl_save_setting', array($this->plugin_admin, 'save_setting'));
		add_action('wp_ajax_asl_load_custom_template', array($this->plugin_admin, 'load_custom_template'));
		add_action('wp_ajax_asl_save_custom_template', array($this->plugin_admin, 'save_custom_template'));
		add_action('wp_ajax_asl_reset_custom_template', array($this->plugin_admin, 'reset_custom_template'));
		add_action('wp_ajax_asl_save_custom_map', array($this->plugin_admin, 'save_custom_map'));		
		add_action('wp_ajax_asl_save_custom_fields', array($this->plugin_admin, 'save_custom_fields'));	
		add_action('wp_ajax_asl_migrate_assets', array($this->plugin_admin, 'migrate_assets'));
		add_action('wp_ajax_asl_backup_tmpl', array($this->plugin_admin, 'backup_template'));
		add_action('wp_ajax_asl_remove_tmpl', array($this->plugin_admin, 'remove_template'));
		add_action('wp_ajax_asl_load_ui_settings', array($this->plugin_admin, 'load_ui_settings'));
		add_action('wp_ajax_asl_save_ui_settings', array($this->plugin_admin, 'save_ui_settings'));

		add_action('wp_ajax_asl_change_options', array($this->plugin_admin, 'change_options'));

		//	Upload the KML file
		add_action('wp_ajax_asl_add_kml', array($this->plugin_admin, 'upload_kml_file'));
		add_action('wp_ajax_asl_delete_kml', array($this->plugin_admin, 'remove_kml_file'));
		
		
		$this->loader->add_action( 'admin_enqueue_scripts', $this->plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $this->plugin_admin, 'enqueue_scripts' );
	}


	/**
	 * [add_admin_menu description]
	 */
	public function add_admin_menu() {
		
		//delete_posts, edit_pages, add_users
		//activate_plugins
		if (current_user_can(ASL_PERMISSION)) {
			
			$svg = 'dashicons-location';
			add_Menu_page('Agile Store Locator', esc_attr__('A Store Locator','asl_admin'), ASL_PERMISSION, 'asl-plugin', array($this->plugin_admin,'admin_plugin_settings'),$svg);
			add_submenu_page( 'asl-plugin', esc_attr__('Dashboard','asl_admin'), esc_attr__('Dashboard','asl_admin'), ASL_PERMISSION, 'agile-dashboard', array($this->plugin_admin,'admin_dashboard'));
			add_submenu_page( 'asl-plugin', esc_attr__('Create New Store','asl_admin'), esc_attr__('Add New Store','asl_admin'), ASL_PERMISSION, 'create-agile-store', array($this->plugin_admin,'admin_add_new_store'));
			add_submenu_page( 'asl-plugin', esc_attr__('Manage Stores','asl_admin'), esc_attr__('Manage Stores','asl_admin'), ASL_PERMISSION, 'manage-agile-store', array($this->plugin_admin,'admin_manage_store'));
			add_submenu_page( 'asl-plugin', esc_attr__('Manage Categories','asl_admin'), esc_attr__('Categories','asl_admin'), ASL_PERMISSION, 'manage-asl-categories', array($this->plugin_admin,'admin_manage_categories'));
			add_submenu_page( 'asl-plugin', esc_attr__('Manage Markers','asl_admin'), esc_attr__('Markers (Pro)','asl_admin'), ASL_PERMISSION, 'manage-store-markers', array($this->plugin_admin,'admin_store_markers'));
			add_submenu_page( 'asl-plugin', esc_attr__('Manage Logos (Pro)','asl_admin'), esc_attr__('Logos (Pro)','asl_admin'), ASL_PERMISSION, 'manage-store-logos', array($this->plugin_admin,'admin_store_logos'));
			add_submenu_page( 'asl-plugin', esc_attr__('Manage Brands (Pro)','asl_admin'), esc_attr__('Brands (Pro)','asl_admin'), ASL_PERMISSION, 'manage-asl-filter', array($this->plugin_admin,'admin_manage_attribute'));
			add_submenu_page( 'asl-plugin', esc_attr__('Manage Specialities (Pro)','asl_admin'), esc_attr__('Specialities (Pro)','asl_admin'), ASL_PERMISSION, 'manage-asl-specials', array($this->plugin_admin, 'admin_manage_specials'));
			add_submenu_page( 'asl-plugin', esc_attr__('Import/Export (Pro)','asl_admin'), esc_attr__('Import/Export (Pro)','asl_admin'), ASL_PERMISSION, 'import-store-list', array($this->plugin_admin,'admin_import_stores'));
			add_submenu_page( 'asl-plugin', esc_attr__('Customize Map','asl_admin'), esc_attr__('Customize Map','asl_admin'), ASL_PERMISSION, 'customize-map', array($this->plugin_admin,'admin_customize_map'));
			add_submenu_page( 'asl-plugin', esc_attr__('ASL Settings','asl_admin'), esc_attr__('ASL Settings','asl_admin'), ASL_PERMISSION, 'user-settings', array($this->plugin_admin,'admin_user_settings'));
			add_submenu_page( 'options-writing.php', esc_attr__('Agile Store Locator UI Customizer','asl_admin'), esc_attr__('Agile Store Locator UI Customizer','asl_admin'), ASL_PERMISSION, 'sl-ui-customizer', array($this->plugin_admin, 'admin_ui_customizer'));

			add_submenu_page('asl-plugin-edit', esc_attr__('Edit Store','asl_admin'), esc_attr__('Edit Store','asl_admin'), ASL_PERMISSION, 'edit-agile-store', array($this->plugin_admin,'edit_store'));
			remove_submenu_page( "asl-plugin", "asl-plugin" );
			remove_submenu_page( "asl-plugin", "asl-plugin-edit" );
			//edit-agile-store
    }
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$this->loader->add_action( 'wp_enqueue_scripts', $this->plugin_public, 'register_styles' );

		//	29-Jan-2022 Registered through Public file
		//$this->loader->add_action( 'wp_enqueue_scripts', $this->plugin_public, 'register_scripts' );

    add_shortcode( 'ASL_STORELOCATOR', array($this->plugin_public, 'frontendStoreLocator'));	
    add_shortcode( 'ASL_STORE', array($this->plugin_public, 'storePage'));
    add_shortcode( 'ASL_LEADFORM', array($this->plugin_public, 'leadForm'));
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_AgileStoreLocator() {
		return $this->AgileStoreLocator;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    AgileStoreLocator_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
